==> wls-plugin-3.7.0-sources.jar: com/xebialabs/deployit/plugin/wls/container/JmsServer.java <==
package com.xebialabs.deployit.plugin.wls.container;

import com.xebialabs.deployit.plugin.api.udm.Metadata;
import com.xebialabs.deployit.plugin.api.udm.Property;
import com.xebialabs.deployit.plugin.api.udm.base.BaseContainer;
import com.xebialabs.deployit.plugin.python.PythonManagingContainer;

import java.util.Set;

import static com.google.common.collect.Sets.newHashSet;

@SuppressWarnings("serial")
@Metadata(description = "WebLogic JMS server, that act as management containers for the queues and topics in JMS modules that are targeted to them")
public class JmsServer extends BaseContainer implements JmsTarget {

    @Property(description = "The tags to map deployables to containers.", required=false)
    private Set<String> tags = newHashSet();

    @Override
    public Set<String> getTags() {
        return tags;
    }

    @Override
    public void setTags(Set<String> tags) {
        this.tags = tags;
    }

    @Property(required = true, asContainment = true, description = "A server instance or migratable target this JMS server is deployed to. 'asContainment'=true, means a JmsServer is 'contained' under a Server")
    private Server server;

    @Override
    public PythonManagingContainer getManagingContainer() {
        return server.getDomain();
    }

    public Server getServer() {
        return server;
    }

    public void setServer(Server server) {
        this.server = server;
    }

    public String getObjectName() {
        return "com.bea:Name=" + getName() + ",Type=JMSServer";
    }

    @Override
    public Domain getDomain() {
        return server.getDomain();
    }
}

==> wls-plugin-3.8.2-sources.jar: com/xebialabs/deployit/plugin/wls/container/JmsServer.java <==
package com.xebialabs.deployit.plugin.wls.container;

import java.util.List;
import java.util.Map;
import java.util.Set;

import com.xebialabs.deployit.plugin.api.flow.Step;
import com.xebialabs.deployit.plugin.api.inspection.Inspect;
import com.xebialabs.deployit.plugin.api.inspection.InspectionContext;
import com.xebialabs.deployit.plugin.api.udm.Metadata;
import com.xebialabs.deployit.plugin.api.udm.Property;
import com.xebialabs.deployit.plugin.api.udm.base.BaseContainer;
import com.xebialabs.deployit.plugin.overthere.Host;
import com.xebialabs.deployit.plugin.overthere.HostContainer;
import com.xebialabs.deployit.plugin.python.ControlTaskDelegate;
import com.xebialabs.deployit.plugin.python.PythonManagingContainer;

import static com.google.common.collect.Sets.newHashSet;

@SuppressWarnings("serial")
@Metadata(description = "WebLogic JMS server, that act as management containers for the queues and topics in JMS modules that are targeted to them")
public class JmsServer extends BaseContainer implements JmsTarget, HostContainer {

    @Property(description = "The tags to map deployables to containers.", required=false)
    private Set<String> tags = newHashSet();

    @Override
    public Set<String> getTags() {
        return tags;
    }

    @Override
    public void setTags(Set<String> tags) {
        this.tags = tags;
    }

    @Property(required = true, asContainment = true, description = "A server instance or migratable target this JMS server is deployed to. 'asContainment'=true, means a JmsServer is 'contained' under a Server")
    private Server server;

    @Override
    public PythonManagingContainer getManagingContainer() {
        return server.getDomain();
    }

    public Server getServer() {
        return server;
    }

    public void setServer(Server server) {
        this.server = server;
    }

    public String getObjectName() {
        return "com.bea:Name=" + getName() + ",Type=JMSServer";
    }

    @Override
    public Domain getDomain() {
        return server.getDomain();
    }

    public List<Step> controlTaskDispatch(String name, Map<String,String> args) {
        return ControlTaskDelegate.dispatch(name, args, this, this);
    }

    @Override
    public Host getHost() {
        return server.getHost();
    }

    @Inspect
    public void inspect(@SuppressWarnings("unused") InspectionContext ctx) {
    }
}
